==> qtmobilehotspot_0.3.3.tar.gz: qtmobilehotspot-0.3.3/qtmhPrivoxy/libqtmhprivoxy-fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>Plugin</name>
    <message>
        <location filename="src/plugin.cpp" line="32"/>
        <source>Privoxy</source>
        <translation>Privoxy</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation type="obsolete">Configuration</translation>
    </message>
    <message>
        <source>Please stop the hotspot before configuring.</source>
        <translation type="obsolete">Veuillez arrêter le hotspot avant de configurer.</translation>
    </message>
    <message>
        <location filename="src/plugin.cpp" line="78"/>
        <source>Error while generating configuration file for privoxy</source>
        <translation>Erreur lors de la génération du fichier de configuration de privoxy</translation>
    </message>
    <message>
        <location filename="src/plugin.cpp" line="83"/>
        <source>Error while generating action file for privoxy</source>
        <translation>Error lors de la génération du fichier d&apos;actions pour privoxy</translation>
    </message>
    <message>
        <location filename="src/plugin.cpp" line="89"/>
        <source>Error while starting privoxy</source>
        <translation>Error lors du démarrage de privoxy</translation>
    </message>
    <message>
        <location filename="src/plugin.cpp" line="94"/>
        <source>Error while setting iptables for privoxy</source>
        <translation>Erreur lors de la mise en place des iptables pour privoxy</translation>
    </message>
    <message>
        <location filename="src/plugin.cpp" line="97"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
</context>
<context>
    <name>PluginGUI</name>
    <message>
        <location filename="src/plugingui.cpp" line="13"/>
        <source>No change</source>
        <translation>Aucun changement</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="14"/>
        <source>MicroB (N900 browser)</source>
        <translation>MicroB (navigateur du N900)</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="15"/>
        <source>Iphone</source>
        <translation>Iphone</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="16"/>
        <source>Custom User-Agent</source>
        <translation>User-Agent personnalisé</translation>
    </message>
</context>
<context>
    <name>PluginGUI2Class</name>
    <message>
        <location filename="src/plugingui2.ui" line="14"/>
        <location filename="src/ui_plugingui2.h" line="156"/>
        <source>Advanced Privoxy...</source>
        <translation>Privoxy avancé...</translation>
    </message>
    <message>
        <location filename="src/plugingui2.ui" line="26"/>
        <location filename="src/ui_plugingui2.h" line="157"/>
        <source>Privoxy port :</source>
        <translation>Port Privoxy :</translation>
    </message>
    <message>
        <source>Enable default actions (from default.action)</source>
        <translation type="obsolete">Activer les actions par défaut (default.action)</translation>
    </message>
    <message>
        <location filename="src/plugingui2.ui" line="38"/>
        <location filename="src/ui_plugingui2.h" line="158"/>
        <source>Enable default Privoxy actions</source>
        <translation>Activer les actions par défaut de Privoxy</translation>
    </message>
    <message>
        <location filename="src/plugingui2.ui" line="45"/>
        <location filename="src/ui_plugingui2.h" line="159"/>
        <source>Enable proxy-forwarding</source>
        <translation>Activer le proxy-forwarding</translation>
    </message>
    <message>
        <location filename="src/plugingui2.ui" line="54"/>
        <location filename="src/ui_plugingui2.h" line="160"/>
        <source>Forward to :</source>
        <translation>Forwarder vers :</translation>
    </message>
    <message>
        <location filename="src/plugingui2.ui" line="64"/>
        <location filename="src/ui_plugingui2.h" line="161"/>
        <source>:</source>
        <translation>:</translation>
    </message>
    <message>
        <location filename="src/plugingui2.ui" line="80"/>
        <location filename="src/ui_plugingui2.h" line="162"/>
        <source>Default</source>
        <translation>Défaut</translation>
    </message>
</context>
<context>
    <name>PluginGUIClass</name>
    <message>
        <location filename="src/plugingui.ui" line="14"/>
        <location filename="src/ui_plugingui.h" line="150"/>
        <source>Privoxy...</source>
        <translation>Privoxy...</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="24"/>
        <location filename="src/ui_plugingui.h" line="151"/>
        <source>Enable Privoxy</source>
        <translation>Activer Privoxy</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="31"/>
        <location filename="src/ui_plugingui.h" line="152"/>
        <source>Proxified ports :</source>
        <translation>Port proxifiés :</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="41"/>
        <location filename="src/ui_plugingui.h" line="153"/>
        <source>User-Agent switching :</source>
        <translation>Switch User-Agent :</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="51"/>
        <location filename="src/ui_plugingui.h" line="154"/>
        <source>Custom User-Agent :</source>
        <translation>User-Agent perso :</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="65"/>
        <location filename="src/ui_plugingui.h" line="155"/>
        <source>Default</source>
        <translation>Défaut</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="85"/>
        <location filename="src/ui_plugingui.h" line="156"/>
        <source>Advanced...</source>
        <translation>Avancé...</translation>
    </message>
</context>
<context>
    <name>pluginGUI2Class</name>
    <message>
        <source>Advanced Privoxy...</source>
        <translation type="obsolete">Privoxy avancé...</translation>
    </message>
    <message>
        <source>Privoxy port :</source>
        <translation type="obsolete">Port Privoxy :</translation>
    </message>
    <message>
        <source>Enable default Privoxy actions</source>
        <translation type="obsolete">Activer les actions par défaut de Privoxy</translation>
    </message>
    <message>
        <source>Enable proxy-forwarding</source>
        <translation type="obsolete">Activer le proxy-forwarding</translation>
    </message>
    <message>
        <source>Forward to :</source>
        <translation type="obsolete">Forwarder vers :</translation>
    </message>
    <message>
        <source>:</source>
        <translation type="obsolete">:</translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="obsolete">Défaut</translation>
    </message>
</context>
</TS>

==> qtmobilehotspot_0.3.4.tar.gz: qtmobilehotspot-0.3.4/qtmhPrivoxy/libqtmhprivoxy-fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>Plugin</name>
    <message>
        <location filename="src/plugin.cpp" line="34"/>
        <source>Privoxy</source>
        <translation>Privoxy</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation type="obsolete">Configuration</translation>
    </message>
    <message>
        <source>Please stop the hotspot before configuring.</source>
        <translation type="obsolete">Veuillez arrêter le hotspot avant de configurer.</translation>
    </message>
    <message>
        <location filename="src/plugin.cpp" line="46"/>
        <source>This plugin allows you to tunnel client&apos;s HTTP connections through the embedded Privoxy.</source>
        <translation>Ce plugin vous permet de faire passer les connexions HTTP des clients à travers un Privoxy intégré.</translation>
    </message>
    <message>
        <location filename="src/plugin.cpp" line="47"/>
        <source>Various functions are available such as user-agent masquerading, content-filtering, proxy-forwarding.</source>
        <translation>Plusieurs fonctions sont disponibles, comme le changement de user-agent, le filtrage de contenu, le proxy-forwarding.</translation>
    </message>
    <message>
        <location filename="src/plugin.cpp" line="48"/>
        <source>You may want to try it if your ISP does not allow data-access via cellphones to PCs.</source>
        <translation>Vous pouvez l&apos;essayer si votre FAI n&apos;autorise pas l&apos;accès à la 3G aux PCs via les téléphones.</translation>
    </message>
    <message>
        <location filename="src/plugin.cpp" line="152"/>
        <source>Error while generating configuration file for privoxy</source>
        <translation>Erreur lors de la génération du fichier de configuration de privoxy</translation>
    </message>
    <message>
        <location filename="src/plugin.cpp" line="157"/>
        <source>Error while generating action file for privoxy</source>
        <translation>Error lors de la génération du fichier d&apos;actions pour privoxy</translation>
    </message>
    <message>
        <location filename="src/plugin.cpp" line="163"/>
        <source>Error while starting privoxy</source>
        <translation>Error lors du démarrage de privoxy</translation>
    </message>
    <message>
        <location filename="src/plugin.cpp" line="168"/>
        <source>Error while setting iptables for privoxy</source>
        <translation>Erreur lors de la mise en place des iptables pour privoxy</translation>
    </message>
    <message>
        <location filename="src/plugin.cpp" line="171"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
</context>
<context>
    <name>PluginGUI</name>
    <message>
        <location filename="src/plugingui.cpp" line="15"/>
        <source>No change</source>
        <translation>Aucun changement</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="16"/>
        <source>MicroB (N900 browser)</source>
        <translation>MicroB (navigateur du N900)</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="17"/>
        <source>Iphone</source>
        <translation>Iphone</translation>
    </message>
    <message>
        <location filename="src/plugingui.cpp" line="18"/>
        <source>Custom User-Agent</source>
        <translation>User-Agent personnalisé</translation>
    </message>
</context>
<context>
    <name>PluginGUI2Class</name>
    <message>
        <source>Advanced Privoxy...</source>
        <translation type="obsolete">Privoxy avancé...</translation>
    </message>
    <message>
        <source>Privoxy port :</source>
        <translation type="obsolete">Port Privoxy :</translation>
    </message>
    <message>
        <source>Enable default actions (from default.action)</source>
        <translation type="obsolete">Activer les actions par défaut (default.action)</translation>
    </message>
    <message>
        <source>Enable default Privoxy actions</source>
        <translation type="obsolete">Activer les actions par défaut de Privoxy</translation>
    </message>
    <message>
        <source>Enable proxy-forwarding</source>
        <translation type="obsolete">Activer le proxy-forwarding</translation>
    </message>
    <message>
        <source>Forward to :</source>
        <translation type="obsolete">Forwarder vers :</translation>
    </message>
    <message>
        <source>:</source>
        <translation type="obsolete">:</translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="obsolete">Défaut</translation>
    </message>
</context>
<context>
    <name>PluginGUIClass</name>
    <message>
        <location filename="src/plugingui.ui" line="14"/>
        <source>Privoxy...</source>
        <translation>Privoxy...</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="29"/>
        <source>Port :</source>
        <translation>Port :</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="74"/>
        <source>Forward to proxy :</source>
        <translation>Forwarder vers :</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="93"/>
        <source>:</source>
        <translation>:</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="125"/>
        <source>Enable default Privoxy actions</source>
        <translation>Activer les actions par défaut de Privoxy</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="141"/>
        <source>User-Agent :</source>
        <translation>User-Agent :</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="167"/>
        <source>Custom :</source>
        <translation>Perso :</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="193"/>
        <source>Privoxy may decrease a little browsing speed, as it is CPU heavy.</source>
        <translation type="unfinished">Privoxy peut réduire la vitesse de navigation car il demande beaucoup de CPU.</translation>
    </message>
    <message>
        <source>Enable Privoxy</source>
        <translation type="obsolete">Activer Privoxy</translation>
    </message>
    <message>
        <location filename="src/plugingui.ui" line="48"/>
        <source>Proxified ports :</source>
        <translation>Port proxifiés :</translation>
    </message>
    <message>
        <source>User-Agent switching :</source>
        <translation type="obsolete">Switch User-Agent :</translation>
    </message>
    <message>
        <source>Custom User-Agent :</source>
        <translation type="obsolete">User-Agent perso :</translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="obsolete">Défaut</translation>
    </message>
    <message>
        <source>Advanced...</source>
        <translation type="obsolete">Avancé...</translation>
    </message>
</context>
<context>
    <name>pluginGUI2Class</name>
    <message>
        <source>Advanced Privoxy...</source>
        <translation type="obsolete">Privoxy avancé...</translation>
    </message>
    <message>
        <source>Privoxy port :</source>
        <translation type="obsolete">Port Privoxy :</translation>
    </message>
    <message>
        <source>Enable default Privoxy actions</source>
        <translation type="obsolete">Activer les actions par défaut de Privoxy</translation>
    </message>
    <message>
        <source>Enable proxy-forwarding</source>
        <translation type="obsolete">Activer le proxy-forwarding</translation>
    </message>
    <message>
        <source>Forward to :</source>
        <translation type="obsolete">Forwarder vers :</translation>
    </message>
    <message>
        <source>:</source>
        <translation type="obsolete">:</translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="obsolete">Défaut</translation>
    </message>
</context>
</TS>
